@@ -1,6 +1,6 @@
  /* ***** BEGIN LICENSE BLOCK *****
  *
- * $Id: encmain.cpp,v 1.79 2008/08/14 02:31:37 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+ * $Id: encmain.cpp,v 1.86 2008/10/29 02:42:06 asuraparaju Exp $ $Name: Dirac_1_0_2 $
  *
  * Version: MPL 1.1/GPL 2.0/LGPL 2.1
  *
@@ -93,6 +93,7 @@ static void display_help()
     cout << "\nDC2K24            bool    false         Use DIGITAL CINEMA 2K compression presets";
     cout << "\nDC4K24           bool    false          Use DIGITAL CINEMA 4K compression presets";
     cout << "\nfull_search     ulong ulong  0UL 0UL         Use full search motion estimation";
+    cout << "\ncombined_me       bool    false         Use a combination of all 3 components to do ME";
     cout << "\nwidth             ulong   Preset        Width of frame";
     cout << "\nheight            ulong   Preset        Length of frame";
     cout << "\nheight            ulong   Preset        Length of frame";
@@ -112,8 +113,8 @@ static void display_help()
     cout << "\nqf                float   0.0F          Overall quality factor (>0, typically: 7=medium, 9=high)";
     cout << "\ntargetrate        ulong   0UL           Target Bit Rate in Kbps";
     cout << "\nlossless          bool    false         Lossless coding (overrides qf)";
-    cout << "\niwlt_filter       string  DD9_7         Intra frame Transform Filter (DD9_7 LEGALL5_3 DD13_7 HAAR0 HAAR1 FIDELITY DAUB9_7)";
-    cout << "\nrwlt_filter       string  LEGALL5_3     Inter frame Transform Filter (DD9_7 LEGALL5_3 DD13_7 HAAR0 HAAR1 FIDELITY DAUB9_7)";
+    cout << "\niwlt_filter       string  DD13_7         Intra frame Transform Filter (DD9_7 LEGALL5_3 DD13_7 HAAR0 HAAR1 FIDELITY DAUB9_7)";
+    cout << "\nrwlt_filter       string  DD13_7     Inter frame Transform Filter (DD9_7 LEGALL5_3 DD13_7 HAAR0 HAAR1 FIDELITY DAUB9_7)";
     cout << "\nwlt_depth         ulong   4             Transform Depth";
     cout << "\nmulti_quants      bool    false         Use multiple quantisers";
     cout << "\nmv_prec           string  false         MV Pixel Precision (1, 1/2, 1/4, 1/8)";
@@ -216,21 +217,21 @@ bool WriteDiagnosticsData (std::ofstream &fdata, dirac_encoder_t *encoder)
                 fdata << instr.refs[i] << " ";
             }
             fdata << instr.ybsep << " " << instr.xbsep << " ";
-            fdata << instr.mb_ylen << " " << instr.mb_xlen << " ";
+            fdata << instr.sb_ylen << " " << instr.sb_xlen << " ";
             fdata << instr.mv_ylen << " " << instr.mv_xlen
                     << std::endl << std::endl ;
-            for (int j=0; j<instr.mb_ylen; j++)
+            for (int j=0; j<instr.sb_ylen; j++)
             {
-                for (int i=0; i<instr.mb_xlen; i++)
-                    fdata << instr.mb_split_mode[j*instr.mb_xlen + i] << " ";
+                for (int i=0; i<instr.sb_xlen; i++)
+                    fdata << instr.sb_split_mode[j*instr.sb_xlen + i] << " ";
                 fdata << std::endl;
             }
             fdata << std::endl;
 
-            for (int j=0; j<instr.mb_ylen; j++)
+            for (int j=0; j<instr.sb_ylen; j++)
             {
-                for (int i=0; i<instr.mb_xlen; i++)
-                    fdata << instr.mb_costs[j*instr.mb_xlen + i] << " ";
+                for (int i=0; i<instr.sb_xlen; i++)
+                    fdata << instr.sb_costs[j*instr.sb_xlen + i] << " ";
                 fdata << std::endl;
             }
             fdata << std::endl;
@@ -672,7 +673,7 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
     // initialise the encoder context
     dirac_encoder_context_init (&enc_ctx, preset);
 
-    //now go over again and override presets with other values
+    //now go over again and override video format presets with other values
     for(int i=1; i < argc; )
     {
         if ( strcmp(argv[i], "-width") == 0 )
@@ -781,7 +782,22 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
                 parsed[i] = false;
             }
         }
-        else if ( strcmp(argv[i], "-field_coding") == 0 )
+    i++;
+    }
+
+    // finally, set the encoding paramters
+
+    // For small pictures, set better (more expensive) parameters
+    if (enc_ctx.src_params.width*enc_ctx.src_params.height<(702*480*2)/3){
+        enc_ctx.enc_params.mv_precision = MV_PRECISION_QUARTER_PIXEL;
+        enc_ctx.enc_params.xblen = 12;
+        enc_ctx.enc_params.yblen = 12;
+        enc_ctx.enc_params.xbsep = 8;
+        enc_ctx.enc_params.ybsep = 8;
+    }
+
+    for (int i=0; i<argc; ){
+        if ( strcmp(argv[i], "-field_coding") == 0 )
         {
             parsed[i] = true;
             enc_ctx.enc_params.picture_coding_mode =  1;
@@ -808,6 +824,11 @@ bool parse_command_line(dirac_encoder_context_t& enc_ctx, int argc, char **argv)
             parsed[i] = true;
 
         }
+        else if ( strcmp(argv[i], "-combined_me") == 0 )
+        {
+            parsed[i] = true;
+            enc_ctx.enc_params.combined_me = 1;
+        }
         else if ( strcmp(argv[i], "-targetrate") == 0 )
         {
             parsed[i] = true;
@@ -1253,10 +1274,11 @@ int main (int argc, char* argv[])
                   << " bits/sec." << std::endl;
 
     if ( verbose )
+    {
         std::cout<<"Time per frame: "<<
            (double)(stop_t-start_t)/(double)(CLOCKS_PER_SEC*frames_loaded);
         std::cout<<std::endl<<std::endl;
-
+    }
    /********************************************************************/
 
      // close the encoder
