@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: common.cpp,v 1.74 2008/08/27 00:17:10 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: common.cpp,v 1.80 2009/01/21 05:21:27 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -208,8 +208,8 @@ void PicturePredParams::SetBlockSizes(const OLBParams& olbparams , const ChromaF
 {
     //given the raw overlapped block parameters, set the modified internal parameters to
     //take account of the chroma sampling format and overlapping requirements, as well
-    //as the equivalent parameters for sub-MBs and MBs.
-    //Does NOT set the number of blocks or macroblocks, as padding may be required.
+    //as the equivalent parameters for sub-SBs and SBs.
+    //Does NOT set the number of blocks or superblocks, as padding may be required.
 
     OLBParams tmp_olbparams = olbparams;
     // Factors for scaling chroma blocks
@@ -452,9 +452,10 @@ void EncoderParams::CalcLambdas(const float qf)
 {
     if (!m_lossless )
     {
-        m_I_lambda = std::pow( 10.0 , (10.0-qf )/2.5 )/16.0;
-        m_L1_lambda = m_I_lambda*8.0;
-        m_L2_lambda = m_I_lambda*64.0;
+        m_I_lambda = std::pow( 10.0 , (12.0-qf )/2.5 )/16.0;
+
+        m_L1_lambda = m_I_lambda*4.0;
+        m_L2_lambda = m_I_lambda*32.0;
 
         // Set the lambdas for motion estimation
         const double me_ratio = 2.0;
@@ -484,7 +485,7 @@ void EncoderParams::SetInterTransformFilter(unsigned int wf_idx)
     SetInterTransformFilter(TransformFilter(wf_idx));
 }
 
-void EncoderParams::SetUsualCodeBlocks ( const PictureType &ftype)
+void EncoderParams::SetUsualCodeBlocks ( const PictureType &/*ftype*/)
 {
     // No subband splitting if  spatial partitioning if false
     // Since this function is common to encoder and decoder we allow the
@@ -494,59 +495,20 @@ void EncoderParams::SetUsualCodeBlocks ( const PictureType &ftype)
         return;
 
     SetCodeBlocks(0, 1, 1);
-    if (TransformDepth() == 0)
+    int depth = TransformDepth();
+    if (depth == 0)
         return;
 
-    switch (GetVideoFormat())
-    {
-    case VIDEO_FORMAT_QSIF525:
-    case VIDEO_FORMAT_QCIF:
-    case VIDEO_FORMAT_CUSTOM:
-    case VIDEO_FORMAT_SIF525:
-    case VIDEO_FORMAT_CIF:
-    case VIDEO_FORMAT_4CIF:
-    case VIDEO_FORMAT_4SIF525:
-    case VIDEO_FORMAT_SD_480I60:
-    case VIDEO_FORMAT_SD_576I50:
-    case VIDEO_FORMAT_HD_720P60:
-    case VIDEO_FORMAT_HD_720P50:
-    case VIDEO_FORMAT_HD_1080I60:
-    case VIDEO_FORMAT_HD_1080I50:
-    case VIDEO_FORMAT_HD_1080P60:
-    case VIDEO_FORMAT_HD_1080P50:
-    case VIDEO_FORMAT_UHDTV_4K60:
-    case VIDEO_FORMAT_UHDTV_4K50:
-    case VIDEO_FORMAT_UHDTV_8K60:
-    case VIDEO_FORMAT_UHDTV_8K50:
-    case VIDEO_FORMAT_DIGI_CINEMA_2K24:
-    case VIDEO_FORMAT_DIGI_CINEMA_4K24:
-        if (ftype == INTRA_PICTURE){
-            int depth = TransformDepth();
-            for (int i=depth; i>=std::max(1,depth-1); --i)
-                SetCodeBlocks(i, Xl()/(24*2^(depth-i)), Yl()/(24*2^(depth-i)));
-            for (int i = 0; i<std::max(1,depth-1); ++i)
-                SetCodeBlocks(i, 1, 1);
-        }
-        else{
-            int depth = TransformDepth();
-            for (int i=depth; i>=std::max(1,depth-3); --i)
-                SetCodeBlocks(i, Xl()/(24*2^(depth-i)), Yl()/(24*2^(depth-i)));
-            for (int i = 0; i<std::max(1,depth-3); ++i)
-                SetCodeBlocks(i, 1, 1);
-        }
-        break;
+    int xl_pad = (Xl() + (1 << depth)-1) & ~((1 << depth)-1);
+    int yl_pad = (Yl() + (1 << depth)-1) & ~((1 << depth)-1);
 
-    default:
-        DIRAC_THROW_EXCEPTION(
-            ERR_INVALID_VIDEO_FORMAT,
-            "Unsupported video format",
-            SEVERITY_PICTURE_ERROR);
-        break;
-    }
+    /* NB, could have different sizes based upon ftype == INTRA_PICTURE */
+    /* aim for 12x12 codeblocks in each subband, execpt the DC with 4x4 */
+    for (int i = 1; i <= depth; i++)
+        SetCodeBlocks(depth-i+1, std::max(1,(xl_pad >> i) /12), std::max(1, (yl_pad >> i) /12));
+    SetCodeBlocks(0, std::max(1,(xl_pad >> depth) /4), std::max(1,(yl_pad >> depth) /4));
 }
 
-
-
 int EncoderParams::GOPLength() const
 {
     if (m_num_L1>0)
