@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: common.h,v 1.78 2008/08/27 00:17:10 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: common.h,v 1.79 2008/10/01 01:26:47 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -160,10 +160,10 @@ namespace dirac
 
         // Macroblock contexts
 
-        MB_SPLIT_BIN1_CTX,  // bin 1, MB split mode vals
-        MB_SPLIT_BIN2_CTX,  // bin 2, MB split mode vals. Bin 3 not required
+        SB_SPLIT_BIN1_CTX,  // bin 1, SB split mode vals
+        SB_SPLIT_BIN2_CTX,  // bin 2, SB split mode vals. Bin 3 not required
 
-        MB_SPLIT_INFO_CTX,  // info context for MB split mode
+        SB_SPLIT_INFO_CTX,  // info context for SB split mode
 
         TOTAL_MV_CTXS       // The total number of motion vector contexts
     };
@@ -990,11 +990,11 @@ namespace dirac
                     m_ref2_weight != 1);
         }
 
-        //! Return the number of macroblocks horizontally
-        int XNumMB() const {return m_x_num_mb;}
+        //! Return the number of superblocks horizontally
+        int XNumSB() const {return m_x_num_sb;}
 
-        //! Return the number of macroblocks vertically
-        int YNumMB() const {return m_y_num_mb;}
+        //! Return the number of superblocks vertically
+        int YNumSB() const {return m_y_num_sb;}
 
         //! Return the number of blocks horizontally
         int XNumBlocks() const {return m_x_num_blocks;}
@@ -1011,11 +1011,11 @@ namespace dirac
         //! Return the number of accuracy bits used for motion vectors
         MVPrecisionType MVPrecision() const { return m_mv_precision; }
 
-        //! Set how many MBs there are horizontally
-        void SetXNumMB(const int xn){m_x_num_mb=xn;}
+        //! Set how many SBs there are horizontally
+        void SetXNumSB(const int xn){m_x_num_sb=xn;}
 
-        //! Set how many MBs there are vertically
-        void SetYNumMB(const int yn){m_y_num_mb=yn;}
+        //! Set how many SBs there are vertically
+        void SetYNumSB(const int yn){m_y_num_sb=yn;}
 
         //! Set how many blocks there are horizontally
         void SetXNumBlocks(const int xn){m_x_num_blocks=xn;}
@@ -1023,7 +1023,7 @@ namespace dirac
         //! Set how many blocks there are vertically
         void SetYNumBlocks(const int yn){m_y_num_blocks=yn;}
 
-        //! Set the block sizes for all MB splitting levels given these prototype block sizes for level=2
+        //! Set the block sizes for all SB splitting levels given these prototype block sizes for level=2
         void SetBlockSizes(const OLBParams& olbparams , const ChromaFormat cformat);
 
         //! Set block level luma params
@@ -1058,11 +1058,11 @@ namespace dirac
 
     private:
 
-        //! The number of macroblocks horizontally
-        int m_x_num_mb;
+        //! The number of superblocks horizontally
+        int m_x_num_sb;
 
-        //! The number of macroblocks verticaly
-        int m_y_num_mb;
+        //! The number of superblocks verticaly
+        int m_y_num_sb;
 
         //! The number of blocks horizontally
         int m_x_num_blocks;
@@ -1111,7 +1111,6 @@ namespace dirac
 
         // Gets ...
 
-
         //! Returns the picture coding mode (independent of source format)
         /*! Returns the picture coding mode (independent of source format)
          *  0 = Frame coding (no quincunx)
@@ -1195,7 +1194,7 @@ namespace dirac
         //! Set Chroma Depth
         void SetChromaDepth(unsigned int chroma_depth) { m_chroma_depth = chroma_depth; }
 
-       //! Set the zero transform flag being used for picture (de)coding
+        //! Set the zero transform flag being used for picture (de)coding
         void SetZeroTransform(bool zero_transform)  { m_zero_transform = zero_transform; }
 
         //! Set the wavelet filter used for picture (de)coding
@@ -1251,7 +1250,7 @@ namespace dirac
         //! chroma depth - number of bits required for luma
         unsigned int m_chroma_depth;
 
-       //! The video format being used
+        //! The video format being used
         VideoFormat m_video_format;
 
        //! Zero transform flag
@@ -1314,6 +1313,9 @@ namespace dirac
         //! Get the vertical search range for full-search motion estimation
         int YRangeME() const {return m_y_range_me;}
 
+        //! Get whether we're doing combined component motion estimation
+        bool CombinedME() const {return m_combined_me; }
+
         //! Get the quality factor
         float Qf() const {return m_qf;}
 
@@ -1396,6 +1398,9 @@ namespace dirac
         //! Set whether we're doing full-search motion estimation
         void SetFullSearch(const bool fs){m_full_search = fs;}
 
+        //! Set whether we're doing combined component motion estimation
+        void SetCombinedME(const bool cme){m_combined_me = cme;}
+
         //! Set the horizontal search range for full-search motion estimation
         void SetXRangeME(const int xr){m_x_range_me = xr;}
 
@@ -1468,6 +1473,9 @@ namespace dirac
         //! A flag indicating whether we're doing full-search block matching
         bool m_full_search;
 
+        //! A flag indicating whether we're doing combined component motion estimation
+        bool m_combined_me;
+
         //! The horizontal range for full-search block matching
         int m_x_range_me;
 
