@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: dirac_encoder.cpp,v 1.54 2008/08/27 00:17:11 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: dirac_encoder.cpp,v 1.57 2008/11/18 23:25:54 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -128,11 +128,11 @@ void copy_mv_cost (const TwoDArray<MvCostData> &pc, dirac_mv_cost_t *dpc)
 */
 void alloc_instr_data(dirac_instr_t *instr)
 {
-    instr->mb_split_mode = new int [instr->mb_ylen*instr->mb_xlen];
-    memset (instr->mb_split_mode, 0, sizeof(int)*instr->mb_ylen*instr->mb_xlen);
+    instr->sb_split_mode = new int [instr->sb_ylen*instr->sb_xlen];
+    memset (instr->sb_split_mode, 0, sizeof(int)*instr->sb_ylen*instr->sb_xlen);
 
-    instr->mb_costs = new float [instr->mb_ylen*instr->mb_xlen];
-    memset (instr->mb_costs, 0, sizeof(float)*instr->mb_ylen*instr->mb_xlen);
+    instr->sb_costs = new float [instr->sb_ylen*instr->sb_xlen];
+    memset (instr->sb_costs, 0, sizeof(float)*instr->sb_ylen*instr->sb_xlen);
 
     instr->pred_mode = new int [instr->mv_ylen * instr->mv_xlen];
     memset (instr->pred_mode, 0, sizeof(int)*instr->mv_ylen*instr->mv_xlen);
@@ -172,11 +172,11 @@ void alloc_instr_data(dirac_instr_t *instr)
 */
 void dealloc_instr_data(dirac_instr_t *instr)
 {
-    if (instr->mb_split_mode)
-        delete [] instr->mb_split_mode;
+    if (instr->sb_split_mode)
+        delete [] instr->sb_split_mode;
 
-    if (instr->mb_costs)
-        delete [] instr->mb_costs;
+    if (instr->sb_costs)
+        delete [] instr->sb_costs;
 
     if (instr->pred_mode)
         delete [] instr->pred_mode;
@@ -246,6 +246,9 @@ public:
     // Return the source parameters
     const SourceParams& GetSrcParams() const { return m_srcparams; }
 
+    // Return the pts offset
+    int GetPTSOffset() const { return m_seqcomp->PTSOffset(); }
+
     // Signal End of Sequence
     void SignalEOS() { m_eos_signalled = true; m_seqcomp->SignalEOS(); }
 
@@ -369,16 +372,16 @@ void DiracEncoder::GetInstrumentationData (dirac_encoder_t *encoder)
     instr->ybsep = m_encparams.GetPicPredParams().LumaBParams(2).Ybsep();
     instr->xbsep = m_encparams.GetPicPredParams().LumaBParams(2).Xbsep();
 
-    // Num macroblocks
-    instr->mb_ylen = m_enc_medata->MBSplit().LengthY();
-    instr->mb_xlen = m_enc_medata->MBSplit().LengthX();
+    // Num superblocks
+    instr->sb_ylen = m_enc_medata->SBSplit().LengthY();
+    instr->sb_xlen = m_enc_medata->SBSplit().LengthX();
 
     // Motion vector array dimensions
     instr->mv_ylen = m_enc_medata->Vectors(1).LengthY();
     instr->mv_xlen = m_enc_medata->Vectors(1).LengthX();
 
-    if (old_instr.mb_ylen != instr->mb_ylen ||
-        old_instr.mb_xlen != instr->mb_xlen ||
+    if (old_instr.sb_ylen != instr->sb_ylen ||
+        old_instr.sb_xlen != instr->sb_xlen ||
         old_instr.mv_ylen != instr->mv_ylen ||
         old_instr.mv_xlen != instr->mv_xlen)
     {
@@ -386,8 +389,8 @@ void DiracEncoder::GetInstrumentationData (dirac_encoder_t *encoder)
         alloc_instr_data(instr);
     }
 
-    copy_2dArray (m_enc_medata->MBSplit(), instr->mb_split_mode);
-    copy_2dArray (m_enc_medata->MBCosts(), instr->mb_costs);
+    copy_2dArray (m_enc_medata->SBSplit(), instr->sb_split_mode);
+    copy_2dArray (m_enc_medata->SBCosts(), instr->sb_costs);
     copy_2dArray (m_enc_medata->Mode(), instr->pred_mode);
     copy_2dArray (m_enc_medata->IntraCosts(), instr->intra_costs);
 
@@ -535,6 +538,7 @@ void DiracEncoder::SetEncoderParams (const dirac_encoder_context_t *enc_ctx)
     m_encparams.SetChromaDepth(chroma_depth);
 
     m_encparams.SetFullSearch(enc_ctx->enc_params.full_search);
+    m_encparams.SetCombinedME(enc_ctx->enc_params.combined_me);
     m_encparams.SetXRangeME(enc_ctx->enc_params.x_range_me);
     m_encparams.SetYRangeME(enc_ctx->enc_params.y_range_me);
     m_encparams.SetCPD(enc_ctx->enc_params.cpd);
@@ -989,11 +993,14 @@ static void SetEncoderParameters(dirac_encoder_context_t *enc_ctx,
     encparams.x_range_me = 32;
     encparams.y_range_me = 32;
 
+    // by default, don't use combined component motion estimation
+    encparams.combined_me = 0;
+
     // set default transform parameters
     WltFilter wf;
-    SetDefaultTransformFilter(INTRA_PICTURE, wf);
+    SetDefaultTransformFilter(INTRA_PICTURE, video_format, wf);
     encparams.intra_wlt_filter = wf;
-    SetDefaultTransformFilter(INTER_PICTURE, wf);
+    SetDefaultTransformFilter(INTER_PICTURE, video_format, wf);
     encparams.inter_wlt_filter = wf;
     encparams.wlt_depth = default_enc_params.TransformDepth();
     encparams.spatial_partition = default_enc_params.SpatialPartition();
@@ -1037,6 +1044,26 @@ extern DllExport dirac_encoder_t *dirac_encoder_init (const dirac_encoder_contex
     return encoder;
 }
 
+#if DIRAC_RESEARCH_VERSION_ATLEAST(1,0,2)
+extern DllExport int dirac_encoder_pts_offset (const dirac_encoder_t *encoder)
+{
+    TEST (encoder != NULL);
+    TEST (encoder->compressor != NULL);
+    DiracEncoder *compressor = (DiracEncoder *)encoder->compressor;
+    int ret;
+    try
+    {
+        ret = compressor->GetPTSOffset();
+    }
+    catch (...)
+    {
+        ret = -1;
+    }
+
+    return ret;
+}
+#endif
+
 extern DllExport int dirac_encoder_load (dirac_encoder_t *encoder, unsigned char *uncdata, int uncdata_size)
 {
     TEST (encoder != NULL);
