@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: picture_compress.cpp,v 1.21 2008/09/16 04:02:19 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: picture_compress.cpp,v 1.28 2009/01/21 05:20:57 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -232,7 +232,7 @@ void PictureCompressor::SubPixelME( EncQueue& my_buffer , int pnum )
 
     if (m_orig_prec != MV_PRECISION_PIXEL)
     {
-        SubpelRefine pelrefine( predparams );
+        SubpelRefine pelrefine( m_encparams );
         pelrefine.DoSubpel( my_buffer , pnum );
     }
     else
@@ -266,7 +266,7 @@ void PictureCompressor::ModeDecisionME( EncQueue& my_buffer, int pnum )
     PictureParams& pparams = my_buffer.GetPicture(pnum).GetPparams();
     PicturePredParams& predparams = me_data.GetPicPredParams();
 
-    ModeDecider my_mode_dec( predparams );
+    ModeDecider my_mode_dec( m_encparams );
     my_mode_dec.DoModeDecn( my_buffer , pnum );
 
     const int num_refs = pparams.NumRefs();
@@ -428,10 +428,20 @@ void PictureCompressor::CodeResidue( EncQueue& my_buffer ,
         /* Do the wavelet transforms and select the component
          * quantisers using perceptual weighting
          */
+	double cpd_scale;
+	if (pparams.PicSort().IsIntra() ){
+	    cpd_scale = 1.0;
+	}
+	else{
+	    float intra_ratio = my_picture.GetMEData().IntraBlockRatio();
+
+            cpd_scale = 5.0*intra_ratio*1.0 + (1.0-5.0*intra_ratio)*0.125;
+	    cpd_scale = std::max( 0.125, std::min( 1.2, cpd_scale ) );
+	}
         for (int c=0; c<3; ++c){
             lambda[c] = GetCompLambda( my_picture, (CompSort) c );
 
-            coeff_data[c]->SetBandWeights( m_encparams , pparams, (CompSort) c);
+            coeff_data[c]->SetBandWeights( m_encparams , pparams, (CompSort) c, cpd_scale);
 
             SubbandList& bands = coeff_data[c]->BandList();
             SetupCodeBlocks( bands );
@@ -552,7 +562,7 @@ if (pparams.IsBPicture() )
             log_picture_lambda= std::log10( m_encparams.L1Lambda() );
 
 //*/
-        float intra_ratio = my_picture.GetMEData().IntraBlockRatio();       
+        float intra_ratio = my_picture.GetMEData().IntraBlockRatio();
 
         lambda= std::pow(10.0,  3.0*intra_ratio*log_intra_lambda+
                          (1.0-3.0*intra_ratio)*log_picture_lambda );
@@ -565,7 +575,7 @@ if (pparams.IsBPicture() )
         lambda*= m_encparams.UFactor();
     if (csort == V_COMP)
         lambda*= m_encparams.VFactor();
-        
+
     return lambda;
 }
 
@@ -617,19 +627,9 @@ void PictureCompressor::SelectQuantisers( CoeffArray& coeff_data ,
 
     // Select all the quantizers
     if ( !m_encparams.Lossless() ){
-        // Set the DC band quantiser to be 1
-        bands( bands.Length() ).SetQuantIndex( 0 );
-        bands( bands.Length() ).SetSkip( false );
-        bands( bands.Length() ).SetUsingMultiQuants( false );
-        est_bits[ bands.Length()] = 0;
-        TwoDArray<CodeBlock>& blocks = bands( bands.Length() ).GetCodeBlocks();
-        for (int j=0; j<blocks.LengthY(); ++j)
-            for (int i=0 ; i<blocks.LengthX(); ++i )
-                blocks[j][i].SetQuantIndex( 0 );
-
-        // Now do the rest of the bands.
-        for ( int b=bands.Length()-1 ; b>=1 ; --b )
-            est_bits[b] = SelectMultiQuants( coeff_data , bands , b, lambda, 
+        // Set quantizers for all bands.
+        for ( int b=bands.Length() ; b>=1 ; --b )
+            est_bits[b] = SelectMultiQuants( coeff_data , bands , b, lambda,
                                       pp, csort );
     }
     else{
