@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_subpel.h,v 1.14 2008/08/27 00:20:52 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: me_subpel.h,v 1.15 2008/10/01 01:26:47 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -47,7 +47,7 @@ namespace dirac
     class EncQueue;
     class MvData;
     class PicArray;
-    
+
     //! The SubpelRefine class takes pixel-accurate motion vectors and refines them to 1/8-pixel accuracy
     /*!
         The SubpelRefine class takes pixel-accurate motion vectors and refines
@@ -57,18 +57,17 @@ namespace dirac
      */
     class SubpelRefine
     {
-    
-    public:
+     public:
         //! Constructor
         /*!
             The constructor initialises the encoder parameters.
-            \param    ppp   the parameters used for controlling ME/MC
+            \param    encp   the parameters used for controlling ME/MC
          */
-        SubpelRefine(const PicturePredParams& ppp);
-    
+        SubpelRefine(const EncoderParams& encp);
+
         //! Destructor
         ~SubpelRefine(){}
-    
+
         //! Does the actual sub-pixel refinement
         /*!
             Does the actual sub-pixel refinement.
@@ -76,38 +75,39 @@ namespace dirac
             \param    pic_num    the picture number on which motion estimation is being performed
          */
         void DoSubpel( EncQueue& my_buffer , int pic_num );
-    
+
     private:
         //! Private, body-less copy constructor: this class should not be copied
         SubpelRefine( const SubpelRefine& cpy );
-    
+
         //! Private, body-less assignment=: this class should not be assigned
         SubpelRefine& operator=( const SubpelRefine& rhs );
-    
+
         //! Match a picture from its (upconverted) reference, and record the block mvs
         void MatchPic(const PicArray& pic_data , const PicArray& refup_data , MEData& me_data ,
                                  int ref_id);
-    
+
         //! Match an individual block
-        void DoBlock( const int xblock , const int yblock , 
+        void DoBlock( const int xblock , const int yblock ,
                       BlockMatcher& my_bmatch, MEData& me_data , const int ref_id );
-    
+
         //! Get a prediction for a block MV from the neighbouring blocks
         MVector GetPred( int xblock , int yblock , const MvArray& mvarray );
-    
+
         //member variables
-    
-        //! A local reference to the encoder params
-        const PicturePredParams& m_predparams;
-    
+
+        //! Local reference to the encoder params
+        const EncoderParams& m_encparams;
+
+        //! A local pointer to the encoder params
+        const PicturePredParams* m_predparams;
+
         //! The list of candidate vectors being tested
         CandidateList m_cand_list;
-    
+
         //! The relative coords of the set of neighbours used to generate MV predictions
         OneDArray<ImageCoords> m_nshift;
-    
-    
-    
+
     };
 
 } // namespace dirac
