@@ -1,6 +1,6 @@
 /* ***** BEGIN LICENSE BLOCK *****
 *
-* $Id: me_utils.cpp,v 1.21 2008/08/14 00:58:24 asuraparaju Exp $ $Name: Dirac_1_0_0 $
+* $Id: me_utils.cpp,v 1.23 2008/10/21 04:55:46 asuraparaju Exp $ $Name: Dirac_1_0_2 $
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
@@ -53,7 +53,7 @@
 using namespace dirac;
 
 #include <algorithm>
-#define INTRA_HAAR
+//#define INTRA_HAAR
 
 void BlockDiffParams::SetBlockLimits( const OLBParams& bparams ,
                                       const PicArray& m_pic_data , 
@@ -284,6 +284,10 @@ void PelBlockDiff::Diff( const BlockDiffParams& dparams,
 ValueType IntraBlockDiff::CalcDC( const BlockDiffParams& dparams ){
 
     CalcValueType int_dc( 0 );
+    if (dparams.Xl() <= 0 || dparams.Yl() <= 0)
+    {
+        return 0;
+    }
 
     for ( int j=dparams.Yp() ; j<dparams.Yp()+dparams.Yl() ; ++j)
         for(int i=dparams.Xp(); i<dparams.Xp()+dparams.Xl() ; ++i )
